// ----- IMPORT ICONS -----
import { RiHome3Fill } from "react-icons/ri";
import { IoMdOptions } from "react-icons/io";
import { FaUsers } from "react-icons/fa";
// ----- IMPORT PAGES -----
import AdministrationPage from "../features/AdministrationPage";
import HomePage from "../features/HomePage";
// ----- IMPORT CONSTS -----
import { ADMINISTRATION } from "../consts";

// ----- TYPE DEFINITIONS -----
type Route = {
	name: string;
	path: string;
	component: () => JSX.Element;
	icon?: () => JSX.Element;
	children?: Route[];
};
type RoutesObject = {
	[key: string]: Route[];
};

// ----- ROUTES DEFINITIONS -----
//! Don't leave trailor '/' in paths
//! Paths in Route should be without base path (even without '/'). If want Route for base path than pass base path
//* Wouter is basically join paths with each other, so if base path is "/" every sub path souldn't have "/" at the beginning

// const routesSecondLevel = {};

const routesFirstLevel: RoutesObject = {
	[ADMINISTRATION]: [
		{
			name: "Users",
			path: "/users",
			component: () => <>UserPage</>,
			icon: FaUsers,
		},
		{
			name: "Roles",
			path: "/roles",
			component: () => <>Roles</>,
		},
		{
			name: "Permissions",
			path: "/permissions",
			component: () => <>Permissions</>,
		},
	],
};

export const routesRoot: Route[] = [
	{
		name: "Home",
		path: "/",
		component: HomePage,
		icon: RiHome3Fill,
	},
	{
		name: ADMINISTRATION,
		path: "administration",
		component: AdministrationPage,
		icon: IoMdOptions,
		children: routesFirstLevel[ADMINISTRATION],
	},
];
